@@ -126,7 +126,7 @@ class powerswitch:
             True = Fail
         """        
         start_status=self.status(outlet)
-        if start_status == 'Off':
+        if start_status == 'OFF':
           return False
         if start_status == 'Unknown':
           return True
@@ -155,7 +155,7 @@ class powerswitch:
             if len(columns) == 5:
                 plugnumber=columns[0].string
                 hostname=columns[1].string
-                state=columns[2].find('font').string
+                state=columns[2].find('font').string.upper()
                 outlets.append([int(plugnumber),hostname,state])
         return outlets
     def printstatus(self):
@@ -168,7 +168,7 @@ class powerswitch:
             print('%d\t%-15.15s\t%s' % (item[0],item[1],item[2]))
         return
     def status(self,outlet=1):
-        """ Return the status of an outlet, returned value will be one of: On, Off, Unknown """
+        """ Return the status of an outlet, returned value will be one of: ON, OFF, Unknown """
         outlets=self.statuslist()
         if outlets and outlet:
             for plug in outlets:
